@@ -1,5 +1,6 @@
 import subprocess
 from qplay_cli.api_clients.qplay import QPlayApiClient
+from ec2_metadata import ec2_metadata
 
 VALID_DATASET_TYPES = ["NSE_EQ", "NSE_OPT", "NSE_FUT"]
 
@@ -123,7 +124,7 @@ class Volume:
                 
         return 0
     
-    def mount_dataset_xvd_type(self, xvd_disks, dataset_type, user_name="MLModel"):
+    def mount_dataset_xvd_type(self, xvd_disks, dataset_type):
         """Mounts given type of dataset on the local machine with xvd* disks. Prints the path where
         the dataset is mounted.
         
@@ -137,7 +138,7 @@ class Volume:
 
         for xvd_disk in xvd_disks:
             xvd_name = xvd_disk.split("/")[-1]
-            vol_info = qplayApiClient.get_volume_info(user_name=user_name, device_name=xvd_name)
+            vol_info = qplayApiClient.get_volume_info(device_name=xvd_name)
             if (dataset_type and vol_info["DatasetType"] == dataset_type) or (vol_info["DatasetType"] in VALID_DATASET_TYPES):
                 
                 print("Valid dataset of {} present in xvd_disk: {}. Will proceed to mounting".format(vol_info["DatasetType"], xvd_disk))
@@ -185,7 +186,29 @@ class Volume:
             self.mount_dataset_xvd_type(xvd_disks, dataset_type)
         else:
             print("No xvd type disks found")
+    
+    
+    def unmount_datasets(self):
+        nvme_volumes = self.list_nvme_volumes()
+        xvd_disks = self.list_xvd_disks()
+        
+        devices_to_umount = list(nvme_volumes.keys()) + xvd_disks
+        
+        if devices_to_umount:
+            print("Unmounting devices {}".format(devices_to_umount))
+        
+            for device in devices_to_umount:
+                command = f"sudo umount {device}"
+                p = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+                out, err = p.communicate()
+                if len(err.decode("ASCII").strip()):
+                    raise Exception("Failed to unmount device {}. Got error: {}".format(device, err))
                 
+                print("Successfully unmounted device {}".format(device))
+        else:
+            print("Nothing to unmount.")
+        
+        
         
         
         
\ No newline at end of file
